@@ -6,7 +6,7 @@ class WithType(Enum):
     CLASSES = auto()
     LINK = auto()
     FLINK = auto()
-    TAG = auto()
+    TAGS = auto()
     XPATH = auto()
     SELECTOR = auto()
 
@@ -19,6 +19,9 @@ class WithType(Enum):
     FATTR = auto()
     BATTR = auto()
     EATTR = auto()
+    NODE = auto()
+    BNODE = auto()
+    FNODE = auto()
     ATTR_WORD = auto()
     VALUE = auto()
     POINT = auto()
@@ -40,7 +43,7 @@ class GenericLocateWith(Enum):
     LINK = auto() 
     FLINK = auto()
     PLINK = auto() 
-    TAG = auto()
+    TAGS = auto()
 
     INDEX = auto()
     WINDOW_TITLE = auto()
@@ -51,11 +54,17 @@ class GenericLocateWith(Enum):
 
     # Translated to XPath
     TEXT = auto() 
-    FTEXT = auto() 
+    FTEXT = auto()
+    BTEXT = auto()
     TITLE = auto() 
     VALUE = auto() 
     ATTR = auto()
     FATTR = auto()
+    BATTR = auto()
+    EATTR = auto()
+    NODE = auto()
+    FNODE = auto()
+    BNODE = auto()
     IMAGE_SRC = auto()
     IMAGE = auto()
 
